@@ -9,12 +9,12 @@ extern "C" {
  CREATOR: eric 23 December 1999
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -22,15 +22,13 @@ extern "C" {
 #ifndef ICALGAUGE_H
 #define ICALGAUGE_H
 #include "libical_icalss_export.h"
-
 /** @file icalgauge.h
  *  @brief Routines implementing a filter for ical components
  */
 typedef struct icalgauge_impl icalgauge;
-LIBICAL_ICALSS_EXPORT icalgauge *icalgauge_new_from_sql(char *sql, int expand);
+LIBICAL_ICALSS_EXPORT icalgauge *icalgauge_new_from_sql(const char *sql, int expand);
 LIBICAL_ICALSS_EXPORT int icalgauge_get_expand(icalgauge *gauge);
 LIBICAL_ICALSS_EXPORT void icalgauge_free(icalgauge *gauge);
-LIBICAL_ICALSS_EXPORT char *icalgauge_as_sql(icalcomponent *gauge);
 LIBICAL_ICALSS_EXPORT void icalgauge_dump(icalgauge *gauge);
 /** @brief Return true if comp matches the gauge.
  *
@@ -39,9 +37,6 @@ LIBICAL_ICALSS_EXPORT void icalgauge_dump(icalgauge *gauge);
  * sub component
  */
 LIBICAL_ICALSS_EXPORT int icalgauge_compare(icalgauge *g, icalcomponent *comp);
-/** Clone the component, but only return the properties
- *  specified in the gauge */
-LIBICAL_ICALSS_EXPORT icalcomponent *icalgauge_new_clone(icalgauge *g, icalcomponent *comp);
 #endif /* ICALGAUGE_H */
 /**
  @file icalset.h
@@ -56,12 +51,12 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalgauge_new_clone(icalgauge *g, icalcompo
 **/
 /*
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -69,9 +64,6 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalgauge_new_clone(icalgauge *g, icalcompo
 #ifndef ICALSET_H
 #define ICALSET_H
 #include "libical_icalss_export.h"
-
-
-
 typedef struct icalset_impl icalset;
 typedef enum icalset_kind
 {
@@ -145,8 +137,6 @@ LIBICAL_ICALSS_EXPORT int icalset_count_components(icalset *set, icalcomponent_k
 /** Restrict the component returned by icalset_first, _next to those
     that pass the gauge. */
 LIBICAL_ICALSS_EXPORT icalerrorenum icalset_select(icalset *set, icalgauge *gauge);
-/** Clears the gauge defined by icalset_select() */
-LIBICAL_ICALSS_EXPORT void icalset_clear_select(icalset *set);
 /** Get a component by uid */
 LIBICAL_ICALSS_EXPORT icalcomponent *icalset_fetch(icalset *set, const char *uid);
 LIBICAL_ICALSS_EXPORT int icalset_has_uid(icalset *set, const char *uid);
@@ -177,19 +167,17 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalsetiter_to_prior(icalset *set, icalseti
  FILE: icalcluster.h
  CREATOR: acampi 13 March 2002
  Copyright (C) 2002 Andrea Campi <a.campi@inet.it>
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
 ======================================================================*/
 #ifndef ICALCLUSTER_H
 #define ICALCLUSTER_H
 #include "libical_icalss_export.h"
-
-
 typedef struct icalcluster_impl icalcluster;
 LIBICAL_ICALSS_EXPORT icalcluster *icalcluster_new(const char *key, icalcomponent *data);
 LIBICAL_ICALSS_EXPORT icalcluster *icalcluster_new_clone(const icalcluster *cluster);
@@ -213,12 +201,12 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalcluster_get_next_component(icalcluster
  FILE: icalfileset.h
  CREATOR: eric 23 December 1999
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -226,15 +214,11 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalcluster_get_next_component(icalcluster
 #ifndef ICALFILESET_H
 #define ICALFILESET_H
 #include "libical_icalss_export.h"
-
-
 typedef struct icalfileset_impl icalfileset;
 LIBICAL_ICALSS_EXPORT icalset *icalfileset_new(const char *path);
 LIBICAL_ICALSS_EXPORT icalset *icalfileset_new_reader(const char *path);
 LIBICAL_ICALSS_EXPORT icalset *icalfileset_new_writer(const char *path);
 LIBICAL_ICALSS_EXPORT icalset *icalfileset_init(icalset *set, const char *dsn, void *options);
-LIBICAL_ICALSS_EXPORT icalfileset *icalfileset_new_from_cluster(const char *path,
-                                                                icalcluster *cluster);
 LIBICAL_ICALSS_EXPORT icalcluster *icalfileset_produce_icalcluster(const char *path);
 LIBICAL_ICALSS_EXPORT void icalfileset_free(icalset *cluster);
 LIBICAL_ICALSS_EXPORT const char *icalfileset_path(icalset *cluster);
@@ -299,12 +283,12 @@ extern icalfileset_options icalfileset_options_default;
  CREATOR: eric 28 November 1999
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -312,7 +296,6 @@ extern icalfileset_options icalfileset_options_default;
 #ifndef ICALDIRSET_H
 #define ICALDIRSET_H
 #include "libical_icalss_export.h"
-
 /* icaldirset Routines for storing, fetching, and searching for ical
  * objects in a database */
 typedef struct icaldirset_impl icaldirset;
@@ -363,12 +346,12 @@ typedef struct icaldirset_options
  FILE: icalcalendar.h
  CREATOR: eric 23 December 1999
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
-  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+ Or:
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -376,14 +359,13 @@ typedef struct icaldirset_options
 #ifndef ICALCALENDAR_H
 #define ICALCALENDAR_H
 #include "libical_icalss_export.h"
-
 /* icalcalendar
  * Routines for storing calendar data in a file system. The calendar
  * has two icaldirsets, one for incoming components and one for booked
  * components. It also has interfaces to access the free/busy list
  * and a list of calendar properties */
 typedef struct icalcalendar_impl icalcalendar;
-LIBICAL_ICALSS_EXPORT icalcalendar *icalcalendar_new(char *dir);
+LIBICAL_ICALSS_EXPORT icalcalendar *icalcalendar_new(const char *dir);
 LIBICAL_ICALSS_EXPORT void icalcalendar_free(icalcalendar *calendar);
 LIBICAL_ICALSS_EXPORT int icalcalendar_lock(icalcalendar *calendar);
 LIBICAL_ICALSS_EXPORT int icalcalendar_unlock(icalcalendar *calendar);
@@ -399,42 +381,38 @@ LIBICAL_ICALSS_EXPORT icalset *icalcalendar_get_freebusy(icalcalendar *calendar)
  CREATOR: eric 21 Aug 2000
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
-  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+ Or:
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  =========================================================================*/
 #ifndef ICALCLASSIFY_H
 #define ICALCLASSIFY_H
 #include "libical_icalss_export.h"
-
-
 LIBICAL_ICALSS_EXPORT icalproperty_xlicclass icalclassify(icalcomponent *c,
                                                           icalcomponent *match, const char *user);
 LIBICAL_ICALSS_EXPORT icalcomponent *icalclassify_find_overlaps(icalset *set,
                                                                 icalcomponent *comp);
-LIBICAL_ICALSS_EXPORT char *icalclassify_class_to_string(icalproperty_xlicclass c);
 #endif /* ICALCLASSIFY_H */
 /*======================================================================
  FILE: icalspanlist.h
  CREATOR: eric 21 Aug 2000
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
 =========================================================================*/
 #ifndef ICALSPANLIST_H
 #define ICALSPANLIST_H
 #include "libical_icalss_export.h"
-
 /** @file icalspanlist.h
  *  @brief Code that supports collections of free/busy spans of time
  */
@@ -448,41 +426,34 @@ LIBICAL_ICALSS_EXPORT icalspanlist *icalspanlist_new(icalset *set,
 /** @brief Destructor
  */
 LIBICAL_ICALSS_EXPORT void icalspanlist_free(icalspanlist *spl);
-/* Unimplemented functions */
-LIBICAL_ICALSS_EXPORT icalcomponent *icalspanlist_make_free_list(icalspanlist *sl);
-LIBICAL_ICALSS_EXPORT icalcomponent *icalspanlist_make_busy_list(icalspanlist *sl);
 /** Get first next free time after time t. all times are in UTC. */
 LIBICAL_ICALSS_EXPORT struct icalperiodtype icalspanlist_next_free_time(icalspanlist *sl,
                                                                         struct icaltimetype t);
-/** Get first next busy time after time t. all times are in UTC. */
-LIBICAL_ICALSS_EXPORT struct icalperiodtype icalspanlist_next_busy_time(icalspanlist *sl,
-                                                                        struct icaltimetype t);
 LIBICAL_ICALSS_EXPORT void icalspanlist_dump(icalspanlist *s);
 /** @brief Return a valid VFREEBUSY component for this span */
-LIBICAL_ICALSS_EXPORT icalcomponent *icalspanlist_as_vfreebusy(icalspanlist *s_in,
+LIBICAL_ICALSS_EXPORT icalcomponent *icalspanlist_as_vfreebusy(icalspanlist *sl,
                                                                const char *organizer,
                                                                const char *attendee);
 /** @brief Return an integer matrix of total events per delta_t timespan */
 LIBICAL_ICALSS_EXPORT int *icalspanlist_as_freebusy_matrix(icalspanlist *span, int delta_t);
 /** @brief Construct an icalspanlist from a VFREEBUSY component */
-LIBICAL_ICALSS_EXPORT icalspanlist *icalspanlist_from_vfreebusy(icalcomponent *c);
+LIBICAL_ICALSS_EXPORT icalspanlist *icalspanlist_from_vfreebusy(icalcomponent *comp);
 #endif
 /*======================================================================
  FILE: icalmessage.h
  CREATOR: eric 07 Nov 2000
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
-  Or:
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+ Or:
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  =========================================================================*/
 #ifndef ICALMESSAGE_H
 #define ICALMESSAGE_H
 #include "libical_icalss_export.h"
-
 LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_accept_reply(icalcomponent *c,
                                                                   const char *user,
                                                                   const char *msg);
@@ -498,20 +469,127 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_delegate_reply(icalcomponen
                                                                     const char *user,
                                                                     const char *delegatee,
                                                                     const char *msg);
-LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_cancel_event(icalcomponent *c,
-                                                                  const char *user,
-                                                                  const char *msg);
-LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_cancel_instance(icalcomponent *c,
-                                                                     const char *user,
-                                                                     const char *msg);
-LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_cancel_all(icalcomponent *c,
-                                                                const char *user, const char *msg);
 LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_error_reply(icalcomponent *c,
                                                                  const char *user,
                                                                  const char *msg,
                                                                  const char *debug,
                                                                  icalrequeststatus rs);
 #endif /* ICALMESSAGE_H */
+/*======================================================================
+ FILE: icalbdbset.h
+ (C) COPYRIGHT 2001, Critical Path
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of either:
+    The LGPL as published by the Free Software Foundation, version
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+ Or:
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at http://www.mozilla.org/MPL/
+======================================================================*/
+#ifndef ICALBDBSET_H
+#define ICALBDBSET_H
+#include "libical_icalss_export.h"
+#include <db.h>
+typedef struct icalbdbset_impl icalbdbset;
+enum icalbdbset_subdb_type
+{ ICALBDB_CALENDARS, ICALBDB_EVENTS, ICALBDB_TODOS, ICALBDB_REMINDERS };
+typedef enum icalbdbset_subdb_type icalbdbset_subdb_type;
+/** sets up the db environment, should be done in parent thread.. */
+LIBICAL_ICALSS_EXPORT int icalbdbset_init_dbenv(char *db_env_dir,
+                                                void (*logDbFunc) (const DB_ENV *,
+                                                                   const char *, const char *));
+LIBICAL_ICALSS_EXPORT icalset *icalbdbset_init(icalset *set, const char *dsn, void *options);
+LIBICAL_ICALSS_EXPORT int icalbdbset_cleanup(void);
+LIBICAL_ICALSS_EXPORT void icalbdbset_checkpoint(void);
+LIBICAL_ICALSS_EXPORT void icalbdbset_rmdbLog(void);
+/** Creates a component handle.  flags allows caller to
+   specify if database is internally a BTREE or HASH */
+LIBICAL_ICALSS_EXPORT icalset *icalbdbset_new(const char *database_filename,
+                                              icalbdbset_subdb_type subdb_type,
+                                              int dbtype, u_int32_t flag);
+LIBICAL_ICALSS_EXPORT DB *icalbdbset_bdb_open_secondary(DB *dbp,
+                                                        const char *subdb,
+                                                        const char *sindex,
+                                                        int (*callback) (DB *db,
+                                                                         const DBT *dbt1,
+                                                                         const DBT *dbt2,
+                                                                         DBT *dbt3), int type);
+LIBICAL_ICALSS_EXPORT char *icalbdbset_parse_data(DBT *dbt, char *(*pfunc) (const DBT *dbt));
+LIBICAL_ICALSS_EXPORT void icalbdbset_free(icalset *set);
+/* cursor operations */
+LIBICAL_ICALSS_EXPORT int icalbdbset_acquire_cursor(DB *dbp, DB_TXN *tid, DBC ** rdbcp);
+LIBICAL_ICALSS_EXPORT int icalbdbset_cget(DBC *dbcp, DBT *key, DBT *data,
+                                          u_int32_t access_method);
+LIBICAL_ICALSS_EXPORT int icalbdbset_cput(DBC *dbcp, DBT *key, DBT *data,
+                                          u_int32_t access_method);
+LIBICAL_ICALSS_EXPORT int icalbdbset_get_first(DBC *dbcp, DBT *key, DBT *data);
+LIBICAL_ICALSS_EXPORT int icalbdbset_get_next(DBC *dbcp, DBT *key, DBT *data);
+LIBICAL_ICALSS_EXPORT int icalbdbset_get_last(DBC *dbcp, DBT *key, DBT *data);
+LIBICAL_ICALSS_EXPORT int icalbdbset_get_key(DBC *dbcp, DBT *key, DBT *data);
+LIBICAL_ICALSS_EXPORT int icalbdbset_delete(DB *dbp, DBT *key);
+LIBICAL_ICALSS_EXPORT int icalbdbset_put(DB *dbp, DBT *key, DBT *data, u_int32_t access_method);
+LIBICAL_ICALSS_EXPORT int icalbdbset_get(DB *dbp, DB_TXN *tid, DBT *key, DBT *data,
+                                         u_int32_t flags);
+LIBICAL_ICALSS_EXPORT const char *icalbdbset_path(icalset *set);
+LIBICAL_ICALSS_EXPORT const char *icalbdbset_subdb(icalset *set);
+/* Mark the set as changed, so it will be written to disk when it
+   is freed. Commit writes to disk immediately. */
+LIBICAL_ICALSS_EXPORT void icalbdbset_mark(icalset *set);
+LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_commit(icalset *set);
+LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_add_component(icalset *set, icalcomponent *child);
+LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_remove_component(icalset *set,
+                                                                icalcomponent *child);
+LIBICAL_ICALSS_EXPORT int icalbdbset_count_components(icalset *set, icalcomponent_kind kind);
+/* Restrict the component returned by icalbdbset_first, _next to those
+   that pass the gauge. _clear removes the gauge */
+LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_select(icalset *store, icalgauge *gauge);
+LIBICAL_ICALSS_EXPORT void icalbdbset_clear(icalset *store);
+/* Get and search for a component by uid */
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_fetch(icalset *set,
+                                                      icalcomponent_kind kind, const char *uid);
+LIBICAL_ICALSS_EXPORT int icalbdbset_has_uid(icalset *set, const char *uid);
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_fetch_match(icalset *set, icalcomponent *c);
+LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_modify(icalset *set, icalcomponent *old,
+                                                      icalcomponent *newc);
+/* cluster management functions */
+LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_set_cluster(icalset *set, icalcomponent *cluster);
+LIBICAL_ICALSS_EXPORT icalerrorenum icalbdbset_free_cluster(icalset *set);
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_get_cluster(icalset *set);
+/* Iterate through components. If a gauge has been defined, these
+   will skip over components that do not pass the gauge */
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_get_current_component(icalset *set);
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_get_first_component(icalset *set);
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_get_next_component(icalset *set);
+/* External iterator for thread safety */
+LIBICAL_ICALSS_EXPORT icalsetiter icalbdbset_begin_component(icalset *set,
+                                                             icalcomponent_kind kind,
+                                                             icalgauge *gauge, const char *tzid);
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_form_a_matched_recurrence_component(icalsetiter *
+                                                                                    itr);
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbsetiter_to_next(icalset *set, icalsetiter *i);
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbsetiter_to_prior(icalset *set, icalsetiter *i);
+/* Return a reference to the internal component. You probably should
+   not be using this. */
+LIBICAL_ICALSS_EXPORT icalcomponent *icalbdbset_get_component(icalset *set);
+LIBICAL_ICALSS_EXPORT DB_ENV *icalbdbset_get_env(void);
+LIBICAL_ICALSS_EXPORT int icalbdbset_begin_transaction(DB_TXN *parent_id, DB_TXN ** txnid);
+LIBICAL_ICALSS_EXPORT int icalbdbset_commit_transaction(DB_TXN *txnid);
+LIBICAL_ICALSS_EXPORT DB *icalbdbset_bdb_open(const char *path,
+                                              const char *subdb,
+                                              int type, int mode, u_int32_t flag);
+typedef struct icalbdbset_options
+{
+    icalbdbset_subdb_type subdb;     /**< the subdatabase to open */
+    int dbtype;                      /**< db_open type: DB_HASH | DB_BTREE */
+    int mode;                        /**< file mode */
+    u_int32_t flag;                  /**< DB->set_flags(): DB_DUP | DB_DUPSORT */
+    char *(*pfunc) (const DBT *dbt);
+                                    /**< parsing function */
+    int (*callback) (DB *db,
+                            /**< callback for secondary db open */
+                     const DBT *dbt1, const DBT *dbt2, DBT *dbt3);
+} icalbdbset_options;
+#endif /* !ICALBDBSET_H */
 
 #ifdef __cplusplus
 }
